//#define DEBUG

void calc_ehh(const int* const data, const int nbr_chr, const int nbr_mrk, const int foc_mrk, const int foc_all,
		const int lim_haplo, const int lim_homo_haplo, const double lim_ehh, const int phased, int* const tot_nbr_chr_in_hap,
		double* const ehh);
